@@ -39,6 +39,7 @@ use warnings;
 
 use App::CELL qw( $CELL );
 use App::Dochazka::CLI qw( $current_emp $debug_mode $prompt_date $prompt_year );
+use App::Dochazka::CLI::Shared qw( shared_generate_report );
 use App::Dochazka::CLI::Util qw( 
     determine_employee
     normalize_date
@@ -96,7 +97,6 @@ our @EXPORT_OK = qw(
     interval_new_date_time_date1_time1
     interval_new_time_time1
     interval_new_timerange
-    interval_summary
 );
 
 
@@ -190,6 +190,8 @@ sub interval_new_timerange {
     EMPLOYEE_SPEC INTERVAL FILLUP _DATE
     INTERVAL SUMMARY _DATE
     EMPLOYEE_SPEC INTERVAL SUMMARY _DATE
+    INTERVAL REPORT _DATE
+    EMPLOYEE_SPEC INTERVAL REPORT _DATE
     INTERVAL DELETE _DATE
     EMPLOYEE_SPEC INTERVAL DELETE _DATE
 
@@ -234,6 +236,8 @@ sub interval_date {
     EMPLOYEE_SPEC INTERVAL FILLUP _DATE _HYPHEN _DATE1
     INTERVAL SUMMARY _DATE _HYPHEN _DATE1
     EMPLOYEE_SPEC INTERVAL SUMMARY _DATE _HYPHEN _DATE1
+    INTERVAL REPORT _DATE _HYPHEN _DATE1
+    EMPLOYEE_SPEC INTERVAL REPORT _DATE _HYPHEN _DATE1
     INTERVAL DELETE _DATE _HYPHEN _DATE1
     EMPLOYEE_SPEC INTERVAL DELETE _DATE _HYPHEN _DATE1
 
@@ -272,6 +276,8 @@ sub interval_date_date1 {
     EMPLOYEE_SPEC INTERVAL FILLUP _MONTH [_NUM]
     INTERVAL SUMMARY _MONTH [_NUM]
     EMPLOYEE_SPEC INTERVAL SUMMARY _MONTH [_NUM]
+    INTERVAL REPORT _MONTH [_NUM]
+    EMPLOYEE_SPEC INTERVAL REPORT _MONTH [_NUM]
     INTERVAL DELETE _MONTH [_NUM]
     EMPLOYEE_SPEC INTERVAL DELETE _MONTH [_NUM]
 
@@ -318,6 +324,8 @@ sub interval_month {
     EMPLOYEE_SPEC INTERVAL FILLUP _NUM [_NUM1]
     INTERVAL SUMMARY _NUM [_NUM1]
     EMPLOYEE_SPEC INTERVAL SUMMARY _NUM [_NUM1]
+    INTERVAL REPORT _NUM [_NUM1]
+    EMPLOYEE_SPEC INTERVAL REPORT _NUM [_NUM1]
     INTERVAL DELETE _NUM [_NUM1]
     EMPLOYEE_SPEC INTERVAL DELETE _NUM [_NUM1]
 
@@ -363,6 +371,8 @@ sub interval_num_num1 {
     EMPLOYEE_SPEC INTERVAL FILLUP _TSRANGE
     INTERVAL SUMMARY _TSRANGE
     EMPLOYEE_SPEC INTERVAL SUMMARY _TSRANGE
+    INTERVAL REPORT _TSRANGE
+    EMPLOYEE_SPEC INTERVAL REPORT _TSRANGE
 
 =cut
 
@@ -394,6 +404,8 @@ sub interval_fillup_tsrange {
     EMPLOYEE_SPEC INTERVAL FILLUP
     INTERVAL SUMMARY
     EMPLOYEE_SPEC INTERVAL SUMMARY
+    INTERVAL REPORT
+    EMPLOYEE_SPEC INTERVAL REPORT
     INTERVAL DELETE
     EMPLOYEE_SPEC INTERVAL DELETE
 
@@ -428,6 +440,8 @@ sub _interval_fillup_delete_print {
         return _delete_intervals_tsrange( $emp->eid, $tsr );
     } elsif ( $th->{'SUMMARY'} ) {
         return _interval_summary( $emp->eid, $tsr );
+    } elsif ( $th->{'REPORT'} ) {
+        return _interval_report( $emp, $tsr );
     } else {
         return _print_intervals_tsrange( $emp, $tsr );
     }
@@ -657,6 +671,36 @@ sub _interval_summary {
         payload => $status->payload );
 }
 
+=head3 _interval_report
+
+Given an employee object and a tsrange, POST to the "genreport" resource with
+an entity body: 
+
+    { 
+        "path" : "suse-cz-monthly.mc", 
+        "parameters" : {
+            "employee" : $EMPLOYEE_OBJECT_JSON,
+            "tsrange" : "$TSRANGE"
+        }
+    }
+
+=cut
+
+sub _interval_report {
+    my ( $emp, $tsr ) = @_;
+    my $emp_json = JSON->new->convert_blessed->encode( $emp );
+    my $entity = <<"EOS";
+{ 
+    "path" : "suse-cz-monthly.mc", 
+    "parameters" : {
+        "employee" : $emp_json,
+        "tsrange" : "$tsr"
+    }
+}
+EOS
+    return shared_generate_report( $entity );
+}
+
 =head3 _fillup
 
 =cut
