@@ -148,6 +148,7 @@ sub _method_echo {
     
     return [ $method, 'echo', $th->{_REST} ];
 } 
+
 # $METHOD FORBIDDEN
 sub _method_forbidden {
     my ( $ts, $th ) = @_;
@@ -156,6 +157,15 @@ sub _method_forbidden {
     return [ $method, 'forbidden', $th->{_REST} ];
 }
 
+# $METHOD HOLIDAY _TSRANGE
+sub _method_holiday_tsrange {
+    my ( $ts, $th ) = @_;
+    my $method = $ts->[0];
+    my $tsrange = $th->{_TSRANGE};
+    
+    return [ $method, "holiday/$tsrange", $th->{_REST} ];
+}
+
 # $METHOD NOOP
 sub _method_noop {
     my ( $ts, $th ) = @_;
